Enum indradb::EdgeDirection [−][src]
pub enum EdgeDirection {
Outbound,
Inbound,
}Specifies what kind of items should be piped from one type of query to another.
Edge and vertex queries can build off of one another via pipes - e.g. you
can get the outbound edges of a set of vertices by piping from a vertex
query to an edge query. EdgeDirections are used to specify which
end of things you want to pipe - either the outbound items or the inbound
items.
Variants
OutboundInbound