Enum indradb::VertexQuery [−][src]
pub enum VertexQuery {
All {
start_id: Option<Uuid>,
limit: u32,
},
Vertices {
ids: Vec<Uuid>,
},
Pipe {
edge_query: Box<EdgeQuery>,
converter: EdgeDirection,
limit: u32,
},
}A query for vertices.
This is used by transactions to get, set and delete vertices and vertex metadata.
Variants
AllFields of All
start_id: Option<Uuid> | |
limit: u32 |
VerticesFields of Vertices
ids: Vec<Uuid> |
PipeFields of Pipe
edge_query: Box<EdgeQuery> | |
converter: EdgeDirection | |
limit: u32 |
Methods
impl VertexQuery[src]
impl VertexQuerypub fn outbound_edges(
self,
t: Option<Type>,
high: Option<DateTime<Utc>>,
low: Option<DateTime<Utc>>,
limit: u32
) -> EdgeQuery[src]
pub fn outbound_edges(
self,
t: Option<Type>,
high: Option<DateTime<Utc>>,
low: Option<DateTime<Utc>>,
limit: u32
) -> EdgeQuerypub fn inbound_edges(
self,
t: Option<Type>,
high: Option<DateTime<Utc>>,
low: Option<DateTime<Utc>>,
limit: u32
) -> EdgeQuery[src]
pub fn inbound_edges(
self,
t: Option<Type>,
high: Option<DateTime<Utc>>,
low: Option<DateTime<Utc>>,
limit: u32
) -> EdgeQueryTrait Implementations
impl Eq for VertexQuery[src]
impl Eq for VertexQueryimpl PartialEq for VertexQuery[src]
impl PartialEq for VertexQueryfn eq(&self, other: &VertexQuery) -> bool[src]
fn eq(&self, other: &VertexQuery) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &VertexQuery) -> bool[src]
fn ne(&self, other: &VertexQuery) -> boolThis method tests for !=.
impl Clone for VertexQuery[src]
impl Clone for VertexQueryfn clone(&self) -> VertexQuery[src]
fn clone(&self) -> VertexQueryReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Debug for VertexQuery[src]
impl Debug for VertexQueryfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for VertexQuery[src]
impl Hash for VertexQueryAuto Trait Implementations
impl Send for VertexQuery
impl Send for VertexQueryimpl Sync for VertexQuery
impl Sync for VertexQuery