Struct indradb::MemoryDatastore [−][src]
An in-memory datastore.
Implementations
impl MemoryDatastore[src]
pub fn read<P: Into<PathBuf>>(
path: P
) -> StdResult<MemoryDatastore, BincodeError>[src]
path: P
) -> StdResult<MemoryDatastore, BincodeError>
Reads a persisted image from disk. Calls to sync will overwrite the file at the specified path.
Arguments
path: The path to the persisted image.
pub fn create<P: Into<PathBuf>>(
path: P
) -> StdResult<MemoryDatastore, BincodeError>[src]
path: P
) -> StdResult<MemoryDatastore, BincodeError>
Creates a new datastore. Calls to sync will overwrite the file at the
specified path, but as opposed to read, this will not read the file
first.
Arguments
path: The path to the persisted image.