[−][src]Struct indradb::SpecificVertexQuery
Gets a specific set of vertices.
Fields
ids: Vec<Uuid>The IDs of the vertices to get.
Methods
impl SpecificVertexQuery[src]
pub fn new(ids: Vec<Uuid>) -> Self[src]
Creates a new vertex query for getting a list of vertices by their IDs.
Arguments
ids- The IDs of the vertices to get.
pub fn single(id: Uuid) -> Self[src]
Creates a new vertex query for getting a single vertex.
Arguments
id- The ID of the vertex to get.