Struct indradb::Vertex
[−]
[src]
pub struct Vertex {
pub id: Uuid,
pub t: Type,
}A vertex.
Vertices are how you would represent nouns in the datastore. An example might be a user, or a movie. All vertices have a unique ID and a type.
Fields
id: Uuid
The id of the vertex.
t: Type
The type of the vertex.
Methods
impl Vertex[src]